#include "mainwindow.h"


MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent) {
    auto menuFile = new QMenu{tr("File")};

    auto actionOpen = new QAction{tr("Open"), this};
    actionOpen->setShortcut(QKeySequence::Open);
    menuFile->addAction(actionOpen);
    connect(actionOpen, SIGNAL(triggered()), this, SLOT(openFile()));

    auto actionCloseAll = new QAction{tr("Close"), this};
    actionCloseAll->setShortcut(QKeySequence::Close);
    menuFile->addAction(actionCloseAll);
    connect(actionCloseAll, SIGNAL(triggered()), this, SLOT(closeAll()));

    auto actionQuit = new QAction{tr("Exit"), this};
    actionQuit->setShortcut(QKeySequence::Quit);
    menuFile->addAction(actionQuit);
    connect(actionQuit, SIGNAL(triggered()), this, SLOT(quit()));

    menuBar()->addMenu(menuFile);

    model = new XmlParser(this);
    treeView = new QTreeView{};
    treeView->setModel(model);
    treeView->setContextMenuPolicy(Qt::CustomContextMenu);
    connect(treeView, SIGNAL(customContextMenuRequested(QPoint)), SLOT(customMenuRequested(QPoint)));
    setCentralWidget(treeView);
}

MainWindow::~MainWindow() {
    delete model;
    delete treeView;
}

void MainWindow::openFile() {
    QString fileName = QFileDialog::getOpenFileName(this, tr("file choice"), QDir::homePath(), tr("XML files (*.xml)"));
    model->LoadFile(fileName);
    treeView->reset();
    QFont font;
    font.setBold(true);
    names.append(fileName);
    model->setData(model->firstIndex(), font, Qt::FontRole);
}

void MainWindow::closeAll() {
    model->closeAll();
    treeView->reset();
    names.clear();
}

void MainWindow::closeFile() {
    auto fileName=model->getName();
    model->close();
    treeView->reset();
    names.removeOne(fileName);
}

void MainWindow::closeFile(const QModelIndex& index){
    model->close(index);
    treeView->reset();
    names.removeOne(model->getNameByIndex(index));
}

void MainWindow::quit() {
    closeAll();
    close();
}


void MainWindow::customMenuRequested(QPoint pos) {
    if (treeView->currentIndex().parent() == treeView->rootIndex() && treeView->indexAt(pos).isValid()) {
        QMenu *menu=new QMenu(this);
        auto actionActive = new QAction{tr("Make active"), this};
        auto actionNew=new QAction{tr("Open in new window"), this};
        menu->addAction(actionActive);
        menu->addAction(actionNew);
        connect(actionActive, &QAction::triggered, this, &MainWindow::makeActive);
        connect(actionNew, &QAction::triggered, this, &MainWindow::openInNewWindow);
        menu->popup(treeView->viewport()->mapToGlobal(pos));
    }
}


void MainWindow::makeActive() {
    auto currentIndex = treeView->currentIndex();
    QFont font;
    font.setBold(true);
    model->setData(currentIndex, font, Qt::FontRole);
}



void MainWindow::openInNewWindow(){
    QModelIndex newWindowFileIndex = treeView->currentIndex();
    QString newWindowFileName = model->getNameByIndex(newWindowFileIndex);
    MainWindow* newW=new MainWindow;
    newW->resize(800, 600);
    newW->show();
    newW->model->LoadFile(newWindowFileName);
    newW->treeView->reset();
    QFont font;
    font.setBold(true);
    newW->names.append(newWindowFileName);
    newW->model->setData(newW->model->firstIndex(), font, Qt::FontRole);
    closeFile(newWindowFileIndex);
}


