#ifndef PARSER_H
#define PARSER_H

#include <QAbstractItemModel>
#include <QFile>
#include <QXmlStreamReader>
#include <QMessageBox>
#include <QStack>

class Tree {
public:
    explicit Tree(const QVector<QVariant> &data, Tree *parentItem = nullptr);
    ~Tree();
    Tree* child(int row);
    void appendChild(Tree* item);
    int rowCount() const;
    int columnCount() const;
    QVariant data(int column) const;
    bool setData(int column, QVariant value);
    Tree* parent() const;
    int rowInParent() const;
    void removeChild();
    void removeChild(int row);
    bool removeChilds(int begin, int end);
private:
    QVector<Tree*> itemChildren;
    QVector<QVariant> itemData;
    Tree* itemParent;
};


class XmlParser : public QAbstractItemModel
{
    Q_OBJECT
public:
    explicit XmlParser(QObject *parent = nullptr);

    QVariant data(const QModelIndex& index, int role) const override;
    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
    Qt::ItemFlags flags(const QModelIndex& p_idx) const override;
    QVariant headerData(int section, Qt::Orientation p_orient, int role = Qt::DisplayRole) const override;
    QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const override;
    QModelIndex parent(const QModelIndex& child) const override;
    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
    int columnCount(const QModelIndex& parent = QModelIndex()) const override;
    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;

    void LoadFile(const QString& fileName);
    void closeAll();
    void close();
    void close(const QModelIndex& index);
    QString getName();
    QString getNameByIndex(const QModelIndex& index);
    QModelIndex firstIndex();

    ~XmlParser();

private:
    Tree* rootItem;
    QXmlStreamReader* xmlReader;
    QPersistentModelIndex focused;
    QFont focusedFont;
};


#endif // PARSER_H
